@@ -1,7 +1,8 @@
 from django.conf import settings
 from geo import get_geo_info
 from geo import get_ip_address
- 
+import defaults
+
 class GeoAwareSessionMiddleware(object):
     """ Saves geo info in session if GeoIP is configured for city or country.
 
@@ -24,7 +25,7 @@ class GeoAwareSessionMiddleware(object):
 
     def process_request(self, request):
         """ Save or update geo info in session """
-        fqdn_or_ip = getattr(settings, 'GEOAWARE_DEBUG_DOMAIN_OR_IP', get_ip_address(request))
+        fqdn_or_ip = getattr(defaults, 'GEOIP_DEBUG_DOMAIN_OR_IP', get_ip_address(request))
         try:
             if request.session['geo_info']['fqdn_or_ip'] == fqdn_or_ip:
                 return None
